import React from 'react';
import SectionHeader from '../ui/section-header';
import { MessageSquare, Code, Zap, Bot, Laptop } from 'lucide-react';

const HowLovableWorksSection = () => {
  return (
    <section id="how-it-works" className="py-12 md:py-16 bg-gradient-to-r from-indigo-50 to-rose-50">
      <div className="container mx-auto px-4">
        <SectionHeader 
          title="How Lovable AI Works" 
          subtitle="Building web applications through natural conversation" 
          centered={true} 
        />
        
        <div className="max-w-4xl mx-auto mt-8 md:mt-10">
          <div className="grid grid-cols-1 md:grid-cols-2 gap-4 md:gap-6 items-center">
            <div className="order-2 md:order-1">
              <div className="bg-white p-4 md:p-6 rounded-lg border border-[#4A36EC]/20 shadow-md">
                <div className="flex items-start gap-3 mb-3 md:mb-4">
                  <div className="bg-gray-100 rounded-full p-2 flex-shrink-0">
                    <MessageSquare className="h-4 w-4 md:h-5 md:w-5 text-gray-600" />
                  </div>
                  <div className="text-xs md:text-sm bg-gray-50 p-2 rounded-lg">
                    <span className="text-gray-700">Create a dashboard with a chart showing monthly sales and a table for customer data.</span>
                  </div>
                </div>
                <div className="flex items-start gap-3 mb-3 md:mb-4">
                  <div className="bg-gradient-to-r from-[#4A36EC] to-[#FF5E5B] rounded-full p-2 flex-shrink-0">
                    <Bot className="h-4 w-4 md:h-5 md:w-5 text-white" />
                  </div>
                  <div className="text-xs md:text-sm bg-gradient-to-r from-[#4A36EC] to-[#FF5E5B] text-white p-2 rounded-lg">
                    <span>I'll create that dashboard for you. I'll use Recharts for the sales chart and implement a sortable table for the customer data.</span>
                  </div>
                </div>
                <div className="mt-3 md:mt-4 text-xs md:text-sm text-gray-500 text-center">Real conversation with Lovable AI</div>
              </div>
            </div>
            <div className="order-1 md:order-2 relative">
              <div className="bg-gray-800 p-4 md:p-6 rounded-lg">
                <div className="flex items-center gap-2 mb-3 md:mb-4">
                  <div className="w-2 h-2 md:w-3 md:h-3 bg-red-500 rounded-full"></div>
                  <div className="w-2 h-2 md:w-3 md:h-3 bg-yellow-500 rounded-full"></div>
                  <div className="w-2 h-2 md:w-3 md:h-3 bg-green-500 rounded-full"></div>
                  <span className="text-gray-300 text-xs md:text-sm ml-2">Live Preview</span>
                </div>
                <div className="bg-gradient-to-br from-[#4A36EC]/20 to-[#FF5E5B]/20 rounded p-3 md:p-4 flex items-center justify-center min-h-[150px] md:min-h-[200px]">
                  <div className="text-center text-white">
                    <Laptop className="h-12 w-12 md:h-16 md:w-16 mx-auto mb-2 md:mb-3 opacity-80" />
                    <p className="text-xs md:text-sm opacity-90">Your app appears here instantly</p>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-4 md:gap-6 mt-8 md:mt-12">
            <div className="bg-white p-4 md:p-6 rounded-lg shadow-md border border-[#4A36EC]/10">
              <div className="text-[#4A36EC] mb-3 md:mb-4 flex items-center justify-center">
                <MessageSquare className="h-6 w-6 md:h-8 md:w-8" />
              </div>
              <h3 className="text-base md:text-lg font-semibold mb-2 text-center">Describe What You Want</h3>
              <p className="text-gray-600 text-center text-sm md:text-base">Simply chat with Lovable AI about what you're trying to build</p>
            </div>
            <div className="bg-white p-4 md:p-6 rounded-lg shadow-md border border-[#FF5E5B]/10">
              <div className="text-[#FF5E5B] mb-3 md:mb-4 flex items-center justify-center">
                <Code className="h-6 w-6 md:h-8 md:w-8" />
              </div>
              <h3 className="text-base md:text-lg font-semibold mb-2 text-center">AI Writes the Code</h3>
              <p className="text-gray-600 text-center text-sm md:text-base">Lovable AI generates clean React code based on your conversation</p>
            </div>
            <div className="bg-white p-4 md:p-6 rounded-lg shadow-md border border-[#4A36EC]/10">
              <div className="bg-gradient-to-r from-[#4A36EC] to-[#FF5E5B] bg-clip-text text-transparent mb-3 md:mb-4 flex items-center justify-center">
                <Zap className="h-6 w-6 md:h-8 md:w-8" />
              </div>
              <h3 className="text-base md:text-lg font-semibold mb-2 text-center">See Results Instantly</h3>
              <p className="text-gray-600 text-center text-sm md:text-base">Watch your application take shape in real-time in the preview window</p>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default HowLovableWorksSection;
